@@ -10,3 +10,7 @@ DEPENDENCIES = (
 )
 
 PROJECTNAME = 'vs.dashboardmanager'
+
+ADD_PERMISSIONS = {
+    'DashboardManager': 'vs.dashboardmanager: Add DashboardManager',
+}
\ No newline at end of file
